/**
 * Lägger till en knapp för att fälla ut eller fälla ihop alla DETAILS-element
 * på en sida.
 */
((doc) => {
    "use strict";

    /**
     * Växla mellan utfällt och hopfällt läge.
     *
     * @param {UIEvent} event Händelseinformation.
     *
     * @return void
     */
    function toggleDetails(event) {
        const btn  = event.target;
        let   open = "false" === btn.getAttribute("aria-expanded");

        // Uppdatera knappens tillstånd
        if (open) {
            btn.setAttribute("aria-expanded", "true");
            btn.innerHTML = "Fäll ihop alla";
        } else {
            btn.setAttribute("aria-expanded", "false");
            btn.innerHTML = "Fäll ut alla";
        }

        // Fäll ut eller fäll ihop alla DETAILS
        doc.querySelectorAll("details")
        .forEach((details) => details.open = open);
    }


    /*
     * Initiering.
     */

    // Kontrollera kompatibilitet
    if ("undefined" === typeof doc.querySelectorAll) {
        return;
    }

    const heading = doc.querySelector("h2:first-of-type");
    if (heading) {
        // Skapa P med BUTTON, infoga före H2-rubriken
        const p = doc.createElement("p");
        p.className = "no-print";

        const btn = p.appendChild(doc.createElement("button"));
        btn.type = "button";
        btn.setAttribute("aria-expanded", "false");
        btn.innerHTML = "Fäll ut alla";
        btn.addEventListener("click", toggleDetails);

        heading.parentNode.insertBefore(p, heading)
    }
})(document);
